import euclidean
import unittest


class TestNonPositiveValueError(unittest.TestCase):

    def test_str(self):
        # We test only that a substring is present
        self.assertIn(" is 3", str(euclidean.NonPositiveValueError(3)))


class TestVector(unittest.TestCase):

    def setUp(self):
        """This will be executed before every test (test_* method)"""
        self.vec = euclidean.Vector(3, 4)

    def test_dimension(self):
        self.assertEqual(self.vec.dimension, 2)

    def test_euclidean_norm(self):
        self.assertEqual(self.vec.euclidean_norm, 5)

    def test_zero_vector(self):
        self.assertEqual(euclidean.Vector(0, 0), euclidean.Vector.zero_vector())

    def test_eq(self):
        self.assertEqual(self.vec, euclidean.Vector(3, 4))
        self.assertNotEqual(self.vec, euclidean.Vector(3, 5))
        self.assertNotEqual(self.vec, euclidean.Vector(2, 4))

    def test_add(self):
        self.assertEqual(self.vec + euclidean.Vector(1, 2), euclidean.Vector(4, 6))

    def test_mul(self):
        self.assertEqual(self.vec * 2, euclidean.Vector(6, 8))

    def test_repr(self):
        self.assertEqual(str(self.vec), "Vector(3, 4)")


class TestYVector(unittest.TestCase):

    def setUp(self):
        self.vec = euclidean.YVector(2)

    def test_x(self):
        self.assertEqual(self.vec.x, 0)


class TestPositiveYVector(unittest.TestCase):

    def setUp(self):
        self.vec = euclidean.PositiveYVector(2)

    def test_init(self):
        with self.assertRaises(euclidean.NonPositiveValueError):
            euclidean.PositiveYVector(-1)


if __name__ == "__main__":
    unittest.main()
